deviceProtocol property
USB-IF protocol code for the device, qualified by the bDeviceClass and bDeviceSubClass values
Implementation
final int deviceProtocol;
USB-IF protocol code for the device, qualified by the bDeviceClass and bDeviceSubClass values
final int deviceProtocol;