bInterfaceSubClass property
USB-IF subclass code for this interface, qualified by the bInterfaceClass value
Implementation
final int bInterfaceSubClass;
USB-IF subclass code for this interface, qualified by the bInterfaceClass value
final int bInterfaceSubClass;