endpoint property
Array of endpoint descriptors. This length of this array is determined by the bNumEndpoints field.
Implementation
final List<UsbEndpointDescriptor> endpoint;
Array of endpoint descriptors. This length of this array is determined by the bNumEndpoints field.
final List<UsbEndpointDescriptor> endpoint;