UvcController class

Constructors

UvcController(Pointer<libusb_device_handle>? handlePtr, UvcControlGetHandler getHandler, UvcControlSetHandler setHandler, {required int bTerminalID, required int bInterfaceNumber, required uvc_device_info info, required String name})

Properties

bInterfaceNumber int
final
bTerminalID int
final
current int?
Get the control current value.
getter/setter pair
defaultValue int?
Get the control default value.
no setter
getHandler UvcControlGetHandler
final
handlePtr Pointer<libusb_device_handle>?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
info uvc_device_info
final
information int?
Get the control info value. TODO: this does not work for zoom absolute get.
no setter
len int?
Get the control length value. TODO: this does not work for zoom absolute get.
no setter
max int?
Get the control maximum value.
no setter
min int?
Get the control minimum value.
no setter
name String
final
resolution int?
Get the control resolution.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setHandler UvcControlSetHandler
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited