UvcCtCtrlSelector enum
Camera terminal control selector (A.9.4)
Values
- controlUndefined → const UvcCtCtrlSelector
-
const UvcCtCtrlSelector(0x00) - scanningModeControl → const UvcCtCtrlSelector
-
const UvcCtCtrlSelector(0x01) - aeModeControl → const UvcCtCtrlSelector
-
const UvcCtCtrlSelector(0x02) - aePriorityControl → const UvcCtCtrlSelector
-
const UvcCtCtrlSelector(0x03) - exposureTimeAbsoluteControl → const UvcCtCtrlSelector
-
const UvcCtCtrlSelector(0x04) - exposureTimeRelativeControl → const UvcCtCtrlSelector
-
const UvcCtCtrlSelector(0x05) - focusAbsoluteControl → const UvcCtCtrlSelector
-
const UvcCtCtrlSelector(0x06) - focusRelativeControl → const UvcCtCtrlSelector
-
const UvcCtCtrlSelector(0x07) - focusAutoControl → const UvcCtCtrlSelector
-
const UvcCtCtrlSelector(0x08) - irisAbsoluteControl → const UvcCtCtrlSelector
-
const UvcCtCtrlSelector(0x09) - irisRelativeControl → const UvcCtCtrlSelector
-
const UvcCtCtrlSelector(0x0a) - zoomAbsoluteControl → const UvcCtCtrlSelector
-
const UvcCtCtrlSelector(0x0b) - zoomRelativeControl → const UvcCtCtrlSelector
-
const UvcCtCtrlSelector(0x0c) - pantiltAbsoluteControl → const UvcCtCtrlSelector
-
const UvcCtCtrlSelector(0x0d) - pantiltRelativeControl → const UvcCtCtrlSelector
-
const UvcCtCtrlSelector(0x0e) - rollAbsoluteControl → const UvcCtCtrlSelector
-
const UvcCtCtrlSelector(0x0f) - rollRelativeControl → const UvcCtCtrlSelector
-
const UvcCtCtrlSelector(0x10) - privacyControl → const UvcCtCtrlSelector
-
const UvcCtCtrlSelector(0x11) - focusSimpleControl → const UvcCtCtrlSelector
-
const UvcCtCtrlSelector(0x12) - digitalWindowControl → const UvcCtCtrlSelector
-
const UvcCtCtrlSelector(0x13) - regionOfInterestControl → const UvcCtCtrlSelector
-
const UvcCtCtrlSelector(0x14)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
UvcCtCtrlSelector> - A constant List of the values in this enum, in order of their declaration.