UvcLib class

A library for controlling UVC compliant webcams.

Constructors

UvcLib({String? libraryName, bool debugLogging = false, bool debugLoggingLibUsb = false})
Loads the library for controlling UVC compliant webcams.

Properties

debugLogging bool
final
debugLoggingLibUsb bool
final
devices → UsbDevices
Access to all USB devices, including UVC devices.
no setter
hashCode int
The hash code for this object.
no setterinherited
isLibraryLoaded bool
Is the libusb library loaded?
no setter
libusb → Libusb
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

control({required int vendorId, required int productId}) UvcControl
Create a camera control for a vendorId and productId. Remember to release the camera with close when you are done using it.
dispose() → void
Release all resources used by this library including the libusb library.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited