UvcPuControlSelector enum

Processing unit control selector (A.9.5)

Inheritance
Available extensions

Values

undefined → const UvcPuControlSelector
backlightCompensation → const UvcPuControlSelector
brightness → const UvcPuControlSelector
contrast → const UvcPuControlSelector
gain → const UvcPuControlSelector
powerLineFrequency → const UvcPuControlSelector
hue → const UvcPuControlSelector
saturation → const UvcPuControlSelector
sharpness → const UvcPuControlSelector
gamma → const UvcPuControlSelector
whiteBalanceTemperature → const UvcPuControlSelector
whiteBalanceTemperatureAuto → const UvcPuControlSelector
whiteBalanceComponent → const UvcPuControlSelector
whiteBalanceComponentAuto → const UvcPuControlSelector
digitalMultiplier → const UvcPuControlSelector
digitalMultiplierLimit → const UvcPuControlSelector
hueAuto → const UvcPuControlSelector
analogVideoStandard → const UvcPuControlSelector
analogLockStatus → const UvcPuControlSelector
contrastAuto → const UvcPuControlSelector

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<UvcPuControlSelector>
A constant List of the values in this enum, in order of their declaration.