uvc_control_interface class

VideoControl interface

Constructors

uvc_control_interface()

Properties

bcdUVC int?
getter/setter pair
bEndpointAddress int?
getter/setter pair
bInterfaceNumber int?
Interface number
getter/setter pair
dwClockFrequency int?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
input_term_descs uvc_input_terminal?
getter/setter pair
processing_unit_descs List<uvc_processing_unit>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited