uvc_device_info class
Constructors
Properties
- config ↔ UsbConfigDescriptor?
-
Configuration descriptor for USB device
getter/setter pair
- ctrl_if ↔ uvc_control_interface?
-
VideoControl interface provided by device
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stream_ifs
↔ List<
uvc_streaming_interface> -
VideoStreaming interfaces on the device
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited