uvc_input_terminal class

Representation of the interface that brings data into the UVC device

Constructors

uvc_input_terminal({required int bTerminalID, required int wTerminalType, required int wObjectiveFocalLengthMin, required int wObjectiveFocalLengthMax, required int wOcularFocalLength, required int bmControls})

Properties

bmControls int
Camera controls (meaning of bits given in {uvc_ct_ctrl_selector})
getter/setter pair
bTerminalID int
Index of the terminal within the device
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wObjectiveFocalLengthMax int
getter/setter pair
wObjectiveFocalLengthMin int
getter/setter pair
wOcularFocalLength int
getter/setter pair
wTerminalType int
Type of terminal (e.g., camera)
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited