uvc_processing_unit class

Constructors

uvc_processing_unit({required int bUnitID, required int bSourceID, required int bmControls})

Properties

bmControls int
Processing controls (meaning of bits given in {uvc_pu_ctrl_selector})
getter/setter pair
bSourceID int
Index of the terminal from which the device accepts images
getter/setter pair
bUnitID int
Index of the processing unit within the device
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited