UsbDevice class
A USB compliant device.
Constructors
- UsbDevice({required int busNumber, required int deviceAddress, required String? path, required UsbSpeed speed, required UsbDeviceDescriptor deviceDescriptor, required UsbConfigDescriptor configurationDescriptor, bool isUvc = false})
- Creates a USB compliant device.
Properties
- busNumber → int
-
Returns the number of the bus.
final
- configurationDescriptor → UsbConfigDescriptor
-
final
- deviceAddress → int
-
Returns the device address.
final
- deviceDescriptor → UsbDeviceDescriptor
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isUvc → bool
-
Is this a UVC device?
final
- path → String?
-
All of the port numbers from root.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- speed → UsbSpeed
-
Get the negotiated connection speed for a device.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited