UsbDeviceDescriptor class
The standard USB device descriptor.
Constructors
- UsbDeviceDescriptor({required int length, required int descriptorType, required int bcdUSB, required int deviceClass, required int deviceSubClass, required int deviceProtocol, required int maxPacketSize0, required int vendorId, required int productId, required int bcdDevice, required int manufacturer, required int product, required int serialNumber, required int numConfigurations, String? manufacturerName, String? productName, String? serialNumberName})
- Creates the standard USB device descriptor.
Properties
- bcdDevice → int
-
Device release number in binary-coded decimal
final
- bcdUSB → int
-
USB specification release number in binary-coded decimal. A value of
0x0200 indicates USB 2.0, 0x0110 indicates USB 1.1, etc.
final
- descriptorType → int
-
Descriptor type. Will have value
\ref libusb_descriptor_type::LIBUSB_DT_DEVICE LIBUSB_DT_DEVICE in this
context.
final
- deviceClass → int
-
USB-IF class code for the device. See \ref libusb_class_code.
final
- deviceProtocol → int
-
USB-IF protocol code for the device, qualified by the bDeviceClass and
bDeviceSubClass values
final
- deviceSubClass → int
-
USB-IF subclass code for the device, qualified by the bDeviceClass
value
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- length → int
-
Size of this descriptor (in bytes)
final
- manufacturer → int
-
Index of string descriptor describing manufacturer
final
- manufacturerName ↔ String?
-
getter/setter pair
- maxPacketSize0 → int
-
Maximum packet size for endpoint 0
final
- numConfigurations → int
-
Number of possible configurations
final
- product → int
-
Index of string descriptor describing product
final
- productId → int
-
USB-IF product ID
final
- productName ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serialNumber → int
-
Index of string descriptor containing device serial number
final
- serialNumberName ↔ String?
-
getter/setter pair
- vendorId → int
-
USB-IF vendor ID
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toHex(
int value) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited