UsbInterfaceDescriptor class
The standard USB interface descriptor.
Constructors
-
UsbInterfaceDescriptor({required int bLength, required int bDescriptorType, required int bInterfaceNumber, required int bAlternateSetting, required int bNumEndpoints, required int bInterfaceClass, required int bInterfaceSubClass, required int bInterfaceProtocol, required int iInterface, required List<
UsbEndpointDescriptor> endpoint, Uint8List? extra}) - Creates the standard USB interface descriptor.
Properties
- bAlternateSetting → int
-
Value used to select this alternate setting for this interface
final
- bDescriptorType → int
-
Descriptor type. Will have value
libusb_descriptor_type::LIBUSB_DT_INTERFACE LIBUSB_DT_INTERFACE
in this context.
final
- bInterfaceClass → int
-
USB-IF class code for this interface. See \ref libusb_class_code.
final
- bInterfaceNumber → int
-
Number of this interface
final
- bInterfaceProtocol → int
-
USB-IF protocol code for this interface, qualified by the
bInterfaceClass and bInterfaceSubClass values
final
- bInterfaceSubClass → int
-
USB-IF subclass code for this interface, qualified by the
bInterfaceClass value
final
- bLength → int
-
Size of this descriptor (in bytes)
final
- bNumEndpoints → int
-
Number of endpoints used by this interface (excluding the control
endpoint).
final
-
endpoint
→ List<
UsbEndpointDescriptor> -
Array of endpoint descriptors. This length of this array is determined
by the bNumEndpoints field.
final
- extra → Uint8List?
-
Extra descriptors. If libusb encounters unknown interface descriptors,
it will store them here, should you wish to parse them.
final
- extraLength → int
-
Length of the extra descriptors, in bytes. Must be non-negative.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- iInterface → int
-
Index of string descriptor describing this interface
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited