UsbSpeed enum
USB Speed codes. Indicates the speed at which the device is operating.
- Inheritance
- Available extensions
Values
- unknown → const UsbSpeed
-
The OS doesn't report or know the device speed.
- low → const UsbSpeed
-
The device is operating at low speed (1.5MBit/s).
- full → const UsbSpeed
-
The device is operating at full speed (12MBit/s).
- high → const UsbSpeed
-
The device is operating at high speed (480MBit/s).
- superNormal → const UsbSpeed
- superPlus → const UsbSpeed
-
The device is operating at super speed plus (10000MBit/s).
Properties
- description → String
-
Available on UsbSpeed, provided by the UsbSpeedExt extension
no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited