UvcControl class
- Available extensions
Constructors
Properties
- backlightCompensation → UvcController
-
Available on UvcControl, provided by the UvcControlExt extension
Backlight compensation: 0: off or 1: onno setter - brightness → UvcController
-
Available on UvcControl, provided by the UvcControlExt extension
Brightnessno setter - contrast → UvcController
-
Available on UvcControl, provided by the UvcControlExt extension
Contrastno setter - debugLogging → bool
-
final
- focus → UvcController
-
Available on UvcControl, provided by the UvcControlExt extension
The Focus control.no setter - focusAuto → UvcController
-
Available on UvcControl, provided by the UvcControlExt extension
Auto focus. A value of 1 means auto focus is on, and a value of 0 means it is off.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- pan → UvcController
-
Available on UvcControl, provided by the UvcControlExt extension
The Pan control.no setter - powerlineFrequency → UvcController
-
Available on UvcControl, provided by the UvcControlExt extension
Powerline frequency: 0: disabled: 1: 50 Hz, 2: 60 Hz: 3: automaticno setter - productId → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- saturation → UvcController
-
Available on UvcControl, provided by the UvcControlExt extension
Saturationno setter -
Available on UvcControl, provided by the UvcControlExt extension
Sharpnessno setter - tilt → UvcController
-
Available on UvcControl, provided by the UvcControlExt extension
The Tilt control.no setter - vendorId → int
-
final
- whiteBalance → UvcController
-
Available on UvcControl, provided by the UvcControlExt extension
White Balanceno setter - zoom → UvcController
-
Available on UvcControl, provided by the UvcControlExt extension
The Zoom absolute control.no setter - zoomRelative → UvcController
-
Available on UvcControl, provided by the UvcControlExt extension
The Zoom relative control.no setter
Methods
-
close(
) → void - Close this camera and release the resources.
-
dispose(
) → void - Close this camera and release the resources.
-
isOpen(
) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resetDevice(
) → bool - Perform a USB port reset for a USB device. Returns true on success.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited