UvcLib class
A library for controlling UVC compliant webcams.
Constructors
Properties
- debugLogging → bool
-
final
- debugLoggingLibUsb → bool
-
final
- devices → UsbDevices
-
Access to all USB devices, including UVC devices.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isLibraryLoaded → bool
-
Is the libusb library loaded?
no setter
- libusb → Libusb
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
control(
{required int vendorId, required int productId}) → UvcControl -
Create a camera control for a
vendorIdandproductId. Remember to release the camera withclosewhen you are done using it. -
dispose(
) → void - Release all resources used by this library including the libusb library.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited