UvcReqCode enum
UVC request code (A.8)
Values
- undefined → const UvcReqCode
-
const UvcReqCode(0x00) - setCurrent → const UvcReqCode
-
const UvcReqCode(0x01) - getCurrent → const UvcReqCode
-
Report the current value
const UvcReqCode(0x81) - getMin → const UvcReqCode
-
Report the minimum supported value
const UvcReqCode(0x82) - getMax → const UvcReqCode
-
Report the maximum supported value
const UvcReqCode(0x83) - getRes → const UvcReqCode
-
Report the resolution (step-size).
const UvcReqCode(0x84) - getLen → const UvcReqCode
-
Report the maximum length of the payload.
const UvcReqCode(0x85) - getInfo → const UvcReqCode
-
???
const UvcReqCode(0x86) - getDef → const UvcReqCode
-
Report the default value
const UvcReqCode(0x87)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
UvcReqCode> - A constant List of the values in this enum, in order of their declaration.