uvc_streaming_interface class
VideoStream interface
Constructors
Properties
- bEndpointAddress ↔ int?
-
USB endpoint to use when communicating with this interface
getter/setter pair
- bInterfaceNumber ↔ int?
-
Interface number
getter/setter pair
- bStillCaptureMethod ↔ int?
-
getter/setter pair
- bTerminalLink ↔ int?
-
getter/setter pair
- format_descs ↔ uvc_format_desc?
-
Video formats that this interface provides
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- next ↔ uvc_streaming_interface?
-
getter/setter pair
- parent ↔ uvc_device_info?
-
getter/setter pair
- prev ↔ uvc_streaming_interface?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited